Monty Python's Flying Circus: Just the Words - Episode 38

# Episode Thirty-eight

Party Political Broadcast (choreographed)
'A Book at Bedtime'
'Redgauntlet'
Kamikaze Scotsmen
No time to lose
Penguins
BBC programme planners
Unexploded Scotsman
'Spot the Loony'
Rival documentaries
'Dad's Doctors' (trail)
'Dad's Pooves' (trail)

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| CAPTION: 'A PARTY POLITICAL BROADCAST ON BEHALF OF THE CONSERVATIVE AND UNIONIST PARTY'
Voice Over | There now follows a Party Political Broadcast on behalf of the Conservative and Unionist Party.
| Cut to a politician sitting on a chair. He is in fact in a rehearsal room, but we don't see this for the first six lines.
Politician | Good evening. Figures talk. We have already fulfilled over three of our election pledges before the end of our second year of good Conservative rule. And, what is more (gets up and starts to do dancing movements as he speaks) We hope ... that in the aut-tumn we shall int-ro-duce leg-is-lat-tion in the House to bene-fit all those in low-er in-come groups. And fur-ther-more we hope...
| Enter a choreographer.
Choreographer | No, no, no, no... look, luv, it's and... (does the movements) one and two and three and four, and five and six and seven and down.
Politician | (trying the last bit) ... five and six and seven and down... it's so much harder with the words.
Choreographer | Well, don't think of them. Just count four in your head.
Politician | And ... one and fur-ther two and three and ... no, I can't really...
Choreographer | Yes, well come on and do it with me, come on. And ...
Both | Fur-ther-more we hope that we can stop the ris-ing un-em-ploy-ment. (they finish up with finger on chin, as in a thirties musical)
Choreographer | And point 'unemployment' with your finger.
Politician | I see. I can do it when you're here.
Choreographer | I won't be far away. All right, Neville love, we're going from 'unemployment' through 'pensions' into 'good government is strong government' and the walk down, all fight? And ... cue, love.
Politician | And fur-ther-more we hope that we can stop the ris-ing un-em-ploy-ment at a stroke or e-ven quick-er.
| Enter a line of six male dancers, doing high kicks and a dance routine.
Dancers | And so when you get a chance to vote, Kind-ly vote Con-ser-va-tive. (the politician joins in) Rising prices, unemployment, Both stem from the wages spiral Curb inflation, save the nation, Join us now and save the economy.
| They give an awful wave and cheesecake smile at the end, and hold it.
Choreographer | That's where you'll get the bunting and the ticker tape, Chris. Right, big smiles, everybody, remember you're cabinet ministers. And relax. (only now do they stop smiling and waving) Lovely, it's trans at eight, so nobody be late.
| The camera crabs away. Through an open door it passes we see two Labour MPs, one on points, the other walking around with his hands on his hips. They are in leotards and dancers' leg warmers.
Labour MPs | We in the Lab-our Par-ty have al-ways made our po-si-tion quite clear... we have al-ways been op-posed to...
| The camera continues to crab away. It comes to a door which says 'Star' on it. We zoom into this and mix through to:
| ANIMATION: Wilson and Heath dance to 'The Dance of the Sugar Plum Fairy'. Cut to the nude organist; he plays a chord. Cut to the announcer at his desk.
Announcer | And now...
It's Man | It's...
| Animated titles. Cut to a studio: a silhouette of a man sitting on a high stool with book.
| SUPERIMPOSED CAPTION: 'A BOOK AT BEDTIME'
Voice Over | 'Book at Bedtime'. Tonight Jeremy Toogood reads 'Redgauntlet' by Sir Walter Scott.
| The lights come up.
Jeremy | Hello. (he follows the words closely with a finger and reads with great difficulty) The sunsoot... the siunsiett... the sunset! .. the sunset... waas... was was... the sunset was... deeing ... d ... ying dying... o ... over... the ... hile ... hiel... heels ... halls ... hills! of... slow ... Sol ... way ... Firth... The... love piper... the lone piper... the lone piper... on... the ... bait ... ly ... ments ... (smiles nervously) ... of Edingrund ... dydburing... Edingbir... Edinburgh! Castle ... was... siluted ... sil ... sillhou...
| Another man enters, takes the book from his hands rather testily and stands by the chair. He smiles apologetically at the camera and reads.
Second Reader | The sunset was dying over the hills of Solway Firth. The lone piper on the battlements of Edinburgh Castle was silhouetted against the crim ... crim ... crimisy... crimson! against the crimson strays ... stree...
| One more reader enters and reads over his shoulder.
Third Reader | Streaked!
Second Reader | Streaked?
Third Reader | Crimson-streaked sky ... in the shadows of... crrignu...
| He can't make out the next word. The second reader also tries to puzzle it out and eventually Jeremy pulls the book down towards him and they all try to puzzle it out. A lot of head shaking. A technician enters wearing headphones.
Technician | Cairngorm! In the shadows of Cairngorm!
Third Reader | In the shadows of Cairngorm, the l... layered...
| A second technician and a make-up girl enter.
Second Technician | Laird! The Laird of Monteu ... Montreaux...
Make-up Girl | Montrose.
All | The Laird of Montrose!
Second Technician | Gal-lopped...
Jeremy | Galloped!
| Everybody joins in helping with words. We mix through to Edinburgh Castle at dusk. The lone piper is silhouetted against the crimson-streaked sky.
Jeremy | (voice over) The lone piper on the battlements of Edinburgh Castle...
| There are a few bars of bagpipe music. Suddenly there is a scream and he disappears. Cut to interior of stone-walled guardroom inside Edinburgh Castle. Ten kilted Scottish guardsmen with bagpipes in a line. A sergeant major at the door taps one on the shoulder.
RSM | Next!
| The next goes outside. We hear pipes start, the sergeant smiles. Cut to castle battlements. The piper plays and then jumps off. We hear the scream as before. Another piper emerges and goes through the same routine.
Voice Over | (Scottish accent) Here on top of Edinburgh Castle, in conditions of extreme secrecy, men are being trained for the British Army's first Kamikaze Regiment, the Queen's Own McKamikaze Highlanders. (there is a scream and a piper jumps off, another one emerges and starts to play) So successful has been the training of the Kamikaze Regiment that the numbers have dwindled from 30,000 to just over a dozen in three weeks. What makes these young Scotsmen so keen to kill themselves?
| Close ups of soldiers.
Scots Soldier | The money's good!
Second Soldier | And the water skiing! (he falls down with a scream)
| Cut to interior of the guardroom in Edinburgh Castle. As before, but with only six men left plus the sergeant major. Bagpipes and a scream. The sergeant major dispatches another man. A captain enters. Bagpipes again.
RSM | Ten-shun.
Captain | All right, sergeant major. At ease. Now, how many chaps have you got left?
RSM | Six, sir,
Captain | Six? (there is a scream)
RSM | Five, sir. (to another highlander carrying bagpipes) Good luck, Johnson. (Johnson leaves)
Captain | Jolly good show, sergeant major. (we hear bagpipes starting up outside) Well, I've come to tell you that we've got a job for your five lads.
| There is a scream.
RSM | Four, sir.
Captain | For your four lads.
RSM | (whispering to another man) Good luck, Taggart.
Taggart | Thank you, sarge. (he goes)
Captain | (looking rather uncertainly at the man leaving) Now this mission's going to be dangerous, (bagpipes start) and it's going to be tough, and we're going to need every lad of yours to pull his weight. (the usual scream in the background) Now, which ... er ... which four are they?
RSM | These three here, sir. OK. Off you go, Smith.
Smith | (with manic eagerness) Right! (he charges out through door before captain can stop him)
Captain | (with mounting concern) ... er ... sergeant major!
RSM | Yes, sir? (bagpipes start outside)
Captain | You don't think it might be a good idea... er... to stop the training programme for a little bit?
RSM | They got to be trained, sir. It's a dangerous job.
Captain | Yes ... I know... but... er ... (the usual scream)
RSM | All right MacPherson, you're next, off you go.
Captain | You see what is worrying me, sergeant major, is...
MacPherson | I'll make it a gud'un, sir! (he dashes off)
RSM | Good luck, MacPherson.
Captain | Er... MacPherson... (the bagpipes start up) only this mission really is very dangerous. We're going to need both the chaps that you've got left (scream)
RSM | Both of who, sir?
Captain | Sergeant major, what's this man's name?
RSM | This one sir? This one is MacDonald, sir.
Captain | No, no, no, no. (the captain stops MacDonald who is straining quite hard to get away) Hang on to MacDonald, sergeant major, hang on to him.
RSM | I don't know whether I can, sir... (MacDonald's eyes are staring in a strange way) he's in a state of Itsubishi Kyoko McSayonara.
Captain | What's that?
| They am both struggling to restrain MacDonald.
RSM | It's the fifth state that a Scotsman can achieve, sir. He's got to finish himself off by lunchtime or he thinks he's let down the Emperor, sir.
Captain | Well, can't we get him out of it?
RSM | Oh, I dunno how to, sir. Our Kamikaze instructor, Mr Yashimoto, was so good he never left Tokyo airport.
Captain | Well, there must be someone else who can advise us?
| Exterior of smart London health-salon-type frontage. A big sign reads 'Kamikaze Advice Centre'. A bowler-hatted man enters. A receptionist sits behind a posh desk.
Man | (very businesslike) Good morning, Kamikaze, please.
Receptionist | (indicating door) Yes, would you go through, please?
Man | Thank you.
| The man walks over to the door, opens it, walks through and disappears from sight. There is nothing but sky and clouds through the door. Scream. Cut back to castle guardroom.
Captain | Right, sergeant major - there's no time to lose.
| The sergeant is sitting on MacDonald. He strikes him on head.
RSM | Beg pardon, sir?
Captain | No time to lose.
RSM | No what, sir?
Captain | No time ... no time to lose.
RSM | Oh, I see, sir. (making gestures) No time ... to ... lose!!
Captain | Yes, that's right, yes.
RSM | Yes, no time to lose, sir!
Captain | Right.
RSM | Isn't that funny, sir... I've never come across that phrase before - 'no time to lose'. Forty-two years I've been in the regular army and I've never heard that phrase.
Captain | Well, it's in perfectly common parlance.
RSM | In what, sir?
Captain | Oh never mind... right ... no time to lose.
RSM | Eventually, yes, sir.
Captain | What?
RSM | Like you say, sir. We'll be able to make time, eventually without to lose, sir, no.
Captain | Look, I don't think you've quite got the hang of this phrase, sergeant major.
| The same frontage of smart London salon as before. Only this time the big sign reads 'No Time To Lose Advice Centre'. The same bowler-hatted man goes in. The same interior, same desk. A consultant sits behind it, and motions for the man to sit down.
Consultant | Morning, no time to lose ... (he picks up a card which reads 'no time to lose'; he keeps flashing it every so often) Now then, how were you thinking of using the phrase?
| He pulls down a blind behind him on the right which also reads 'no time to lose' in large letters. He lets it go and it rolls up again fast.
Man | Well, I was thinking of using it ... er .. like .., well ... 'good morning dear, what is in no time to lose?'
Consultant | Er yes ... well ... you've not quite got the hang of that, have you.
| He gets out a two-foot-square cube with 'no time to lose' in the same lettering as it always is, and puts it on the desk. He points to this in a manic way with a forefinger. He has the words 'no time to lose' on the back of his hand.
Consultant | (sings) No time to lose, no time to lose, no time to lose, no time to lose. (to stop the manic fit he reaches inside desk, pours a drink from a bottle on which is written 'no time to lose') Now, you want to use this phrase in everyday conversation, is that right?
Man | Yes, that's right.
Consultant | Yes ... good ...
| He stands up, makes a strange noise, and flings the back of his jacket up over his head revealing 'no time to lose' written on the inside of the back lining of his jacket, upside down so that it is the right way up when it is revealed.
Man | You see my wife and I have never had a great deal to say to each other ... (tragic, heart-rending music creeps in under the dialogue) In the old days we used to find things to say, like 'pass the sugar'... or, 'that's my flannel', but in the last ten or fifteen years there just hasn't seemed to be anything to say, and anyway I saw your phrase advertised in the paper and I thought, that's the kind of thing I'd like to say to her...
| The consultant pushes down a handle and a large screen comes up in front of him. On it is written 'no time to lose'. He burts through the paper.
Consultant | Yes, well, what we normally suggest for a beginner such as yourself, is that you put your alarm clock back ten minutes in the morning, so you can wake up, look at the clock and use the phrase immediately. (he holds up the card briefly) Shall we try it?
Man | Yes.
Consultant | All right - I'll be the alarm clock. When I go off, look at me and use the phrase, OK? (ticks then imitates ringing)
Man | No! Time to lose!
Consultant | No... No time to lose.
Man | No time to lose?
Consultant | No time to lose.
Man | No time to lose.
Consultant | No - to lose... like Toulouse in France. No time Toulouse.
Man | No time too lose...
Consultant | No time Toulouse.
Man | No time Toulouse...
Consultant | No! - no time to lose!
Man | No - no time to lose!
| ANIMATION: Toulouse-Lautrec in a wild-west gunfight.
Voice Over | No-time Toulouse. The story of the wild and lawless days of the post-Impressionists.
| Cut back to the guardroom at Edinburgh Castle. MacDonald is edging towards the window.
Captain | Anyway, no time to lose, sergeant major.
RSM | Look out, sir! MacDonald!
| They both rush to window and grab MacDonald's legs as he disappears through it.
RSM | We'll have to hurry, sir. (they haul him back into the room to reveal he is carrying a saw with which he starts trying to saw off his head) No, put that down MacDonald. (he snatches the saw and throws it away) He's reached the sixth plane already, sir.
Captain | Right, here are the plans sergeant major, good luck.
RSM | Thank you, sir. (he salutes)
| MacDonald is by now trying to strangle himself with his bare hands.
Captain | And good luck to you, MacDonald.
| MacDonald breaks off from strangling himself, to offer a snappy salute.
MacDonald | Thank you, sir.
| He immediately snaps back into trying to strangle himself.
RSM | Right you are, MacDonald. No time to lose.
Captain | Very good, sergeant major.
| Quick cut to the consultant in the office.
Consultant | Yes, excellent...
| Cut back to the gates of Edinburgh Castle. Dawn. Music. As the voice starts the gates open and a lorry emerges.
Voice Over | So it was that on a cold November morning, RSM Urdoch and Sapper MacDonald, one of the most highly trained Kamikaze experts the Scottish Highlands have ever witnessed, left on a mission which was to... oh I can't go on with this drivel.
| By this time we have cut to a close up of the cab to show RSM Urdoch at the wheel, with MacDonald beside him. MacDonald has a revolver and is apparently having an unsuccessful game of Russian roulette.
RSM | All right, MacDonald, no time to lose.
| Suddenly MacDonald hurls himself out of the lorry.
MacDonald | Aaaaaaugh!
| The RSM slams the brakes on. Skidding noises. Cut to shot of the lorry skidding to a halt. The RSM leaps out, picks up MacDonald who is lying on the floor hitting himself, and loads him into the back of the lorry. He gets back into the lorry and they start off again. They haven't gone more than a few yards before we see MacDonald leap out of the back of the lorry, race round to the front and throw himself down in front of the lorry. The lorry runs right over him. He picks himself up after it has gone, races up to the front and tries it again... and again... and again... and again... and again... Cut to the captain, standing in front of a huge map. He points with a stick.
Captain | Well, that's the mission - now here's the method. RSM Murdoch will lull the enemy into a false sense of security by giving them large quantities of money, a good home, and a steady job. Then, when they're upstairs with the wife, Sapper MacDonald will hurl himself at the secret documents, destroying them and himself. Well, that's the plan, the time is now 19.42 hours. I want you to get to bed, have a good night's rest and be up on parade early in the morning. Thank you for listening and thank you for a lovely supper.
| Pull out to reveal that he is in a very small sitting room, alone apart from his wife who sits knitting by the fire not listening to a word he's saying. Cut to the 'Book at Bedtime' set. Seven or eight technicians, a make-up girl. etc. still crowding around Toogood as he tries to read.
Toogood | And...and...sue...so...the...the...intripid...
Make-up Girl | Intrepid.
All | Intrepid.
Toogood | Intrepid RSM Urdoch and super...
Technician | Sapper.
Toogood | Sapper MacDonald...mead...
Several | Made!
Toogood | Made their why...
Several | Way!
Toogood | Way toarra...
Make-up Girl | Towards...
Toogood | Towards the Rusty...Ritzy...
All | Russian!
Toogood | Russian bolder...
All | Border!
| Map with an animated line showing the route.
Toogood's Voice | ...and so RSM Urdoch and Sapper MacDonald made their way towards the Russian bolder...
All | Border!!...Border.
| ANIMATION: the line becomes part of an animated skit on the famous film '2001'. Cut to stock film on penguins.
| SUPERIMPOSED CAPTIONS: 'FRONTIERS OF MEDICINE PART 2' 'THE GATHERING STORM'
| Cut to presenter at desk.
Presenter | Penguins, yes, penguins. What relevance do penguins have to the furtherance of medical science? Well, strangely enough quite a lot, a major breakthrough, maybe. It was from such an unlikely beginning as an unwanted fungus accidentally growing on a sterile plate that Sir Alexander Fleming gave the world penicillin. James Watt watched an ordinary household kettle boiling and conceived the potentiality of steam power. Would Albert Einstein ever have hit upon the theory of relativity if he hadn't been clever? All these tremendous leaps forward have been taken in the dark. Would Rutherford ever have split the atom if he hadn't tried? Could Marconi have invented the radio if he hadn't by pure chance spent years working at the problem? Are these amazing breakthroughs ever achieved except by years and years of unremitting study? Of course not. What I said earlier about accidental discoveries must have been wrong. Nevertheless scientists believe that these penguins, these comic flightless web-footed little bastards may finally unwittingly help man to fathom the uncharted depths of the human mind. Professor Rosewall of the Laver Institute.
| A scientist with tennis courts in the background. He wears a white coat.
| SUPERIMPOSED CAPTION: 'PROF. KEN ROSEWALL'
Scientist | (Australian accent) Hello. Here at the Institute Professor Charles Pasarell, Dr Peaches Bartkowicz and myself have been working on the theory originally postulated by the late Dr Kramer that the penguin is intrinsically more intelligent than the human being.
| He moves over to a large diagram which is being held by two tennis players in full tennis kit but wearing the brown coats of ordinary laboratory technicians. The diagram shows a penguin and a man in correct proportional size with their comparative brain capacities marked out clearly showing the man's to be much larger than the penguin's.
Scientist | The first thing that Dr Kramer came up with was that the penguin has a much smaller brain than the man. This postulate formed the fundamental basis of all his thinking and remained with him until his death.
| Flash cut of elderly man in tennis shirt and green eye shade getting an arrow in the head. Cut back to the scientist now with diagram behind him. It shows a man and a six foot penguin.
Scientist | Now we've taken this theory one stage further. If we increase the size of the penguin until it is the same height as the man and then compare the relative brain sizes, we now find that the penguin's brain is still smaller. But, and this is the point, it is larger than it was.
| Very quick cut of tennis crowd going 'oh' and applauding. Dr Peaches Bartkowicz standing by tennis net.
| SUPERIMPOSED CAPTION: 'DR PEACHES BARTKOWICZ'
Peaches | For a penguin to have the same size of brain as a man the penguin would have to be over sixty-six feet high.
| She moves to the left and comes upon a cut-out of the lower visible part of a sixty-six feet high penguin. She looks up at it. Cut back to the scientist.
Scientist | This theory has become known as the waste of time theory and was abandoned in 1956. (slight edit with jump visible) Hello again. Standard IQ tests gave the following results. The penguins scored badly when compared with primitive human sub-groups like the bushmen of the Kalahari but better than BBC programme planners. (he refers to graph decorated with little racquets which shows bushmen with 23, penguins with 13 and BBC planners' with 8) The BBC programme planners surprisingly high total here can be explained away as being within the ordinary limits of statistical error. One particularly dim programme planner can cock the whole thing up.
| CAPTION: 'YOU CAN SAY THAT AGAIN'
| Cut to a tennis player in a changing room taking off his gym shoes. In the background two other players discuss shots.
| SUPERIMPOSED CAPTION: 'DR LEWIS HOAD'
Hoad | These IQ tests were thought to contain an unfair cultural bias against the penguin. For example, it didn't take into account the penguins extremely poor educational system. To devise a fairer system of test, a team of our researchers spent eighteen months in Antarctica living like penguins, and subsequently dying like penguins - only quicker - proving that the penguin is a clever little sod in his own environment.
| Cut to the scientist.
Scientist | Therefore we devised tests to be given to the penguins in the fourth set ... I do beg your pardon, in their own environment.
Voice | Net!
Scientist | Shh!
| Cut to a professor and team surrounding penguins standing in a pool.
Professor | What is the next number in this sequence - 2, 4, 6. . .
| A penguin squawks.
Professor | Did he say eight? ... (sighs) What is...
| Cut back to the scientist.
Scientist | The environmental barrier had been removed but we'd hit another: the language barrier. The penguins could not speak English and were therefore unable to give the answers. This problem was removed in the next series of experiments by asking the same questions to the penguins and to a random group of non-English-speaking humans in the same conditions.
| Cut to the professor and his team now surrounding a group of foreigners who are standing in a pool looking bewildered.
Professor | What is the next number? 2, 4, 6... (long pause)
Swedish Person | . . . Hello?
| Cut back to the scientist.
Scientist | The results of these tests were most illuminating. The penguins scores were consistently equal to those of the non-English-speaking group.
| Cut to the foreigners having fish thrown at them, which they try to catch in their mouths, and a penguin with a menu at a candlelit table with a woman in evening dress and a waiter trying to take an order. Cut to Dr Hoad taking a shower.
Hoad | These enquiries led to certain changes at the BBC ...
| Cut to the boardroom of BBC. Penguins sit at a table with signs saying 'Programme Controller', 'Head of Planning', 'Director General'. Noise of penguins squawking. Cut to the penguin pool Hoad's voice ever.
Hoad | While attendances at zoos boomed.
| The camera pans across to a sign reading 'The programme planners are to be fed at 3 o'clock'.
Voice Over | Soon these feathery little hustlers were infiltrating important positions everywhere.
| Mr. Gilliam's animation shows penguins infiltrating important positions everywhere. Cut to RSM Urdoch having his lorry checked by a penguin border guard.
| SUPERIMPOSED CAPTION: 'MEANWHILE AT A CHECKPOINT ON THE RUSSO-POLISH BORDER'
| The lorry drives off past a sign saying 'Russian bolder' with 'bolder' crossed out and 'border' written in. Cut to Red Square.
| SUPERIMPOSED CAPTION: 'THE KREMLIT'
| The 't' is crossed out and 'n ' written in. Cut to two Russian majors in a conference room.
First Major | Svientitzi hobonwy kratow sveguminurdy.
| SUPERIMPOSED SUBTITLES: 'THESE ARE THE VERY IMPORTANT SECRET DOCUMENTS I WAS TELLING YOU ABOUT'
Second Major | We must study them in conditions of absolute secrecy.
| Superimposed subtitle in Russian.
First Major | (speaks in Russian)
| SUPERIMPOSED SUBTITLE: 'WHAT?'
Second Major | (looking up) Look out!
| SUPERIMPOSED SUBTITLE: 'REGARDEZ LA!'
| They cower as MacDonald flashes through the skylight and lands on the table where he lies rigid with his knees drawn up. He ticks ominously.
Second Major | He hasn't gone off.
| SUPERIMPOSED CAPTION: 'ZE HABE NICHT GESHPLODEN'
First Major | (speaks in Russian)
| SUBTITLE: 'QUICK! RING THE UNEXPLODED SCOTSMAN SQUAD'
Second Major | Yes my General!
| Superimposed subtitle in Chinese.
| Cut to a phone ringing on the branch of a tree. Pull back to show a Scotsman lying on his back with his knees drawn up in the middle of a field. Two Russian bomb experts are crawling towards him cautiously.
| SUPERIMPOSED CAPTION: 'UNEXPLODED SCOTSMAN DISPOSAL SQUAD'
| They go to work on him. Tense close ups. They sweat. Finally they remove his head. One of them runs hurriedly and places it in a bucket labelled 'Vodka '.
| SUPERIMPOSED CAPTION: 'WHISKY'
| The sound of drunken gurglings comes from the bucket. Pull back to show that this is on a screen at the back of a panel game set. Fade it out as camera in studio pans down to the presenter.
Presenter | And welcome to 'Spot the Loony', where once again we invite you to come with us all over the world to meet all kinds of people in all kinds of places, and ask you to . .. Spot the Loony! (crescendo of music)
| SUPERIMPOSED CAPTION: 'ALL ANSWERS VERIFIED BY ENCYCLOPAEDIA BRITANNICA'
Presenter | Our panel this evening... Gurt Svensson, the Swedish mammal abuser and part-time radiator.
| Cut to Svensson. He is standing on his head on the desk with his legs crossed in a yoga position. He wears a loincloth and high-heeled shoes. He talks through a megaphone which is strapped to his head.
Svensson | Good evening.
| Cut back to the presenter.
Presenter | Dame Elsie Occluded, historian, wit, bon viveur, and rear half of the Johnson brothers...
| Cut to another section of the panel's desk. Dame Elsie. Her bottom half is encased in the side of a block of concrete which is also on top of the desk. Dame Elsie is thus parallel to the ground. She has fairy wings on her back, a striped t-shirt, flying gloves, goggles and a green wig.
Dame Elsie | Good evening.
| Cut back to the presenter.
Presenter | And Miles Yellowbird, up high in banana tree, the golfer and inventor of Catholicism.
| Cut to final section of the desk. A man dressed as a rabbit, with a megaphone strapped to one eye.
Miles | Good evening.
Presenter | And we'll be inviting them to... Spot the Loony. (a phone rings on the desk; he picks it up) Yes? Quite right ... A viewer from Preston there who's pointed out correctly that the entire panel are loonies. Five points to Preston there, and on to our first piece of film. It's about mountaineering and remember you have to... Spot the Loony!
| Cut to a shot of a mountain. Very impressive stirring music.
Voice Over | The legendary south face of Ben Medhui, dark ... forbidding...
| In the middle distance are two bushes a few yards apart. At this point a loony dressed in a long Roman toga, with tam o'shanter, holding a cricket bat, runs from one bush to the other. Loud buzz. The film freezes. Pull out from screen to reveal the freeze frame of the film with the loony in the middle bush on the screen immediately behind the presenter. The presenter is on the phone.
Presenter | Yes, well done, Mrs Nesbitt of York, spotted the loony in 1.8 seconds. (cut to stock fiilm of Women's Institute applauding) On to our second round, and it's photo time. We're going to invite you to look at photographs of Tony Jacklin, Anthony Barber, Edgar Allan Poe, Katy Boyle, Reginald Maudling, and a loony. All you have to do is ... Spot the Loony! (cut to a photo of Anthony Barber; the buzzer goes immediately) No ... I must ask you please not to ring in until you've seen all the photos.
| Back to the photo sequence and music. Each photo is on the screen for only two seconds, and in between each there is a click as of a slide projector changing or even the sound of the shutter of a camera. The photos show in sequence: Anthony Barber, Katy Boyle, Edgar Allan Poe, a loony head and shoulders. He has ping-pong ball eyes, several teeth blocked out, a fright wig and his chest is bare but across it is written 'A Loony', Reginald Maudling, Tony Jacklin. A buzzer sounds.
Presenter | Yes, you're right. The answer was, of course, number two! (cut to stock film of Women's Institute applauding) I'm afraid there's been an error in our computer. The correct answer should of course have been number four, and not Katy Boyle. Katy Boyle is not a loony, she is a television personality. (fanfare as for historical pageant; a historical-looking shield comes up on screen) And now it's time for 'Spot the Loony, historical adaptation'. (historical music) And this time it's the thrilling medieval romance 'Ivanoe'... a stirring story of love and war, violence and chivalry, set midst the pageantry and splendour of thirteenth-century England. All you have to do is, 'Spot the Loony'.
| CAPTION: 'IVANOE'
| Cut to a butcher shop. A loony stands in the middle (this is the same loony from 'Silly Election' with enormous trousers and arms inside them and green fright wig). Another loony in a long vest down to his knees with a little frilly tutu starting at the knees and bare feet is dancing with a side of beef also wearing a tutu. Another loony in oilskins with waders and sou'wester and fairy wings is flying across the top of picture. Another man dressed us a bee is standing on the counter. Another loony is dressed as a carrot leaning against the counter going: 'pretty boy, pretty boy'. A cocophony of noise. We see this sight for approximately five seconds. Fantastic loud buzzes.
Presenter | Yes, well done, Mrs L of Leicester, Mrs B of Buxton and Mrs G of Gotwick, the loony was of course the writer, Sir Walter Scott.
| Cut to Sir Walter Scott in his study.
| SUPERIMPOSED CAPTION: 'SIR WALTER SCOTT 1771 - 1832,
Scott | (looking through his papers indignantly) I didn't write that! Sounds more like Dickens...
| Cut to Dickens at work in his study. He looks up.
| SUPERIMPOSED CAPTION: 'CHARLES DICKENS 1812 - 1870'
Dickens | You bastard!
| Cut to a documentary producer standing in forested hillside.
First Producer | Was Sir Walter Scott a loony, or was he the greatest flowering of the early nineteenth-century romantic tradition? The most underestimated novelist of the nineteenth century... (another introducer of documentaries comes into shot and walks up to the first) . . . or merely a disillusioned and embittered man ...
Second Producer | Excuse me ... (pointing at the microphone) can I borrow that, please.
First Producer | ... yes.
Second Producer | Thank you. (he immediately starts on his own documentary) These trees behind me now were planted over forty years ago, as part of a policy by the then Crown Woods, who became the Forestry Commission in 1924. (he starts to walk towards the forest) The Forestry Commission systematically replanted this entire area...
| The first producer follows behind.
First Producer | Excuse me.
Second Producer | Sh! That's forty thousand acres of virgin forest. By 1980 this will have risen to two hundred thousand acres of soft woods. In commercial terms, a coniferous cornucopia... an evergreen El Dorado... (the first producer runs and makes a feeble grab for the mike)... a tree-lined treasure trove ... No ... a fat fir-coned future for the financiers ... but what of the cost ...
First Producer | It's mine!
Second Producer | (to first producer) Go away ... in human terms? Who are the casualties?
| The first producer makes a lunge and grabs the mike. He stops and the camera stops with him.
First Producer | For this was Sir Walter Scott's country. Many of his finest romances, such as 'Guy Mannering' and 'Redgauntlet'...
Second Producer | Give that back!
First Producer | No. (they grapple a bit. The first producer just manages to keep hold of it as he goes down onto the ground) Scott showed himself to be not only a fine...
| The second producer manages to grab the mike and runs off leaving the first producer on the ground. The camera follows the second producer.
Second Producer | (running) The spruces and flowers of this forest will be used to create a whole new industry here in...
| The first producer brings him down with a diving rugger tackle and grabs the mike.
First Producer | ... also a writer of humour and...
| They are both fighting and rolling around on the ground.
Second Producer | Britain's timber resources are being used up at a rate of...
| The first producer hits him, and grabs the mike.
First Producer | One man who knew Scott was Angus Tinker.
| A sunlit university quad with classical pillars. Gentle classical music. Tinker is standing next to one of the pillars. He is a tweed-suited academic.
| CAPTION: 'ANGUS TINKER'
Tinker | Much of Scott's greatest work, and I'm thinking here particularly of 'Heart of Midlothian' and 'Old Mortality' for example, was concerned with... (at this point a hand appears from behind the pillar and starts to go slowly but surely for the mike) preserving the life and conditions of a... (the mike is grabbed away from him)
Voice | Forestry research here has shown that the wholly synthetic soft timber fibre can be created... (Tinker looks behind the pillar to discover a forestry expert in tweeds crouched) ... leaving the harder trees, the oaks, the beeches and the larches... (Tinker chases him out into the quad) and the pines, and even some of the deciduous hardwoods.
| CAPTION: 'A FORESTRY EXPERT'
Forestry Expert | This new soft-timber fibre would totally replace the plywoods, hardboards and chipboards at present dominating the...
| A Morris Minor speeds up round the quad and passes straight in front of the expert and the first producer's hand comes out and grabs the mike. Cut to interior of the Morris Minor as it speeds out of quad and out into country. The first producer keeps glancing nervously over shoulder.
First Producer | In the Waverley novels... Scott was constantly concerned to protect a way of life...
| He ducks as we hear the sound of a bullet ricochet from the car. Cut to shot through the back window. The second producer is chasing in a huge open American 1930's gangster car driven by a chauffeur in a thirties kit. He is shooting.
First Producer | ....safeguarding nationalist traditions and aspiration, within the necessary limitations of the gothic novel...
| More bullets. The American car draws level. The second producer leans over trying to grab the mike. Still attempting to say their lines, both of them scramble for the microphone as the cars race along. Eventually the cars disappear round a corner and we hear a crash. Cut to Toogood, surrounded by people, holding the book very close to his face and peering closely at the print. MacDonald lies on the floor in front of them.
Toogood | Then... theen... the... the end! The End. (looks up)
| Cut to film (no sound) of Edward Heath. The 'Spot the Loony' buzzer goes. Roll credits. Cut to BBC world symbol.
Voice Over | Next week on 'Book at Bedtime', Jeremy Toogood will be reading Anna Sewell's Black Bu...Bue...Burton...Blakc Bottoon...(fade out)
| Fade BBC world symbol back up.
Continuity Voice | Tomorrow night comedy returns to BBC TV with a new series of half-hour situation comedies for you to spot the winners. Ronnie Thompson stars in 'Dad's Doctor'... (cut to a doctor with no trousers)
| SUPERIMPOSED CAPTION: 'DAD'S DOCTOR'
Continuity Voice | ... the daffy exploits of the RAMC training school. He's in charge of a group of mad medicos, and when they run wild it's titty jokes galore. (medical students run past him waving bras) Newcomer Veronica Papp plays the girl with the large breasts. (a young lady runs past wearing only briefs) Week two sees the return of the wacky exploits of the oddest couple you've ever seen - yes, 'Dad's Pooves'...
| A kitchen set. A man (Terry G) in sexy female underwear. Another man (Terry J) dressed as a judge runs in with flowers.
| SUPERIMPOSED CAPTION: 'DAD'S POOVES'
Continuity Voice | ... the kooky oddball laugh-a-minute fun-a-plenty world of unnatural sexual practices. (the first man spanks the judge with a string of sausages) Week three brings a change of pace with a new comedy schedule. With Reg Cuttleworth, Trevor Quantas, and Cindy Rommel as Bob, in 'On the Dad's Liver Bachelors at Large', (caption of this title and several loony still photos of the cast) keeping the buses running from typical bedsit land in pre-war Liverpool. That's followed by 'The Ratings Game' - the loony life of a BBC programme planner with the accent on repeats. (Michael's loony again)
| SUPERIMPOSED CAPTION: 'THE RATINGS GAME'
Continuity Voice | Edie Phillips-Bong plays Kevin Vole, the programme planner with a problem and his comic attempts to pass the time. Week six sees the return of 'Up The Palace'... (stock film of the investiture of the Prince of Wales)
| SUPERIMPOSED CAPTION: 'UP THE PALACE'
Continuity Voice | ... the zany exploits of a wacky Queen, and that's followed by 'Limestone, Dear Limestone'... (long shot of a cliff with two people high up on it)
| SUPERIMPOSED CAPTION: 'LIMESTONE DEAR LIMESTONE'
Continuity Voice | ... the wacky days of the late Pleistocene era when much of Britain's rock strata was being formed. All this and less on 'Comedy Ahoy'. But now, BBC Television is closing down for the night. Don't forget to switch off your sets. Goodnight.
| We see the little dot as of a TV set bring switched off.